pub fn check_public_shares(
poly_comm: &PolyCommitment,
threshold: usize,
ctx: &[u8],
) -> boolExpand description
Check that the PolyCommitment is properly signed and has the correct degree polynomial
pub fn check_public_shares(
poly_comm: &PolyCommitment,
threshold: usize,
ctx: &[u8],
) -> boolCheck that the PolyCommitment is properly signed and has the correct degree polynomial